@@ -6,10 +6,7 @@ from __future__ import absolute_import, division, print_function
 
 import sys
 import datetime
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
+import unittest
 
 import os
 
