@@ -9,10 +9,7 @@ test.run()
 
 """
 import sys
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
+import unittest
 import os
 
 from ioflo import test
