@@ -4,10 +4,7 @@ Unit Test Template
 """
 
 import sys
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
+import unittest
 
 import os
 import time
